@@ -185,14 +185,14 @@ class InvoiceLine:
         if self.product:
             if self.product.principals:
                 if self.principal not in self.product.principals:
-                    self.principal = self.product.default_principal
+                    self.principal = self.product.principal
             elif self.principal:
                 self.principal = None
 
     @classmethod
     def view_attributes(cls):
         return super(InvoiceLine, cls).view_attributes() + [
-            ('//page[@id="commissions"]', 'state', {
+            ('//page[@id="commissions"]', 'states', {
                     'invisible': Eval('type') != 'line',
                     })]
 
